@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.118';
+our $VERSION = '0.119';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Mon Mar 18 13:44:02 2019 GMT
+# on Sat Apr 13 15:20:01 2019 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1727,7 +1727,7 @@ __PACKAGE__->status( add => 25042, iridium => '-', 'Iridium 39', 'Tumbling' );
 __PACKAGE__->status( add => 25043, iridium => '-', 'Iridium 38', 'Tumbling' );
 __PACKAGE__->status( add => 25077, iridium => '-', 'Iridium 42', 'Tumbling' );
 __PACKAGE__->status( add => 25078, iridium => '-', 'Iridium 44', 'Tumbling' );
-__PACKAGE__->status( add => 25104, iridium => '+', 'Iridium 45', '' );
+__PACKAGE__->status( add => 25104, iridium => '-', 'Iridium 45', 'Tumbling' );
 __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
 __PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-09-01' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
@@ -1739,14 +1739,14 @@ __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-0
 __PACKAGE__->status( add => 25173, iridium => 'D', 'Iridium 53', 'Decayed 2018-09-30' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
-__PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
+__PACKAGE__->status( add => 25272, iridium => 'D', 'Iridium 55', 'Decayed 2019-03-31' );
 __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
-__PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
+__PACKAGE__->status( add => 25274, iridium => 'D', 'Iridium 58', 'Decayed 2019-04-07' );
 __PACKAGE__->status( add => 25275, iridium => 'D', 'Iridium 59', 'Decayed 2019-03-11' );
 __PACKAGE__->status( add => 25276, iridium => 'D', 'Iridium 60', 'Decayed 2019-03-17' );
 __PACKAGE__->status( add => 25285, iridium => 'D', 'Iridium 62', 'Decayed 2018-11-07' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
-__PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
+__PACKAGE__->status( add => 25287, iridium => 'D', 'Iridium 64', 'Decayed 2019-04-01' );
 __PACKAGE__->status( add => 25288, iridium => 'D', 'Iridium 65', 'Decayed 2018-07-19' );
 __PACKAGE__->status( add => 25289, iridium => 'D', 'Iridium 66', 'Decayed 2018-08-23' );
 __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-07-02' );
@@ -1777,16 +1777,16 @@ __PACKAGE__->status( add => 25778, iridium => 'D', 'Iridium 21', 'Decayed 2018-0
 __PACKAGE__->status( add => 27372, iridium => 'D', 'Iridium 91', 'Decayed 2019-03-13' );
 __PACKAGE__->status( add => 27373, iridium => 'D', 'Iridium 90', 'Decayed 2019-01-23' );
 __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-04-18' );
-__PACKAGE__->status( add => 27375, iridium => 'S', 'Iridium 95', '' );
+__PACKAGE__->status( add => 27375, iridium => 'D', 'Iridium 95', 'Decayed 2019-03-25' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 2
-#       Spare [S]: 6
-#    Tumbling [-]: 32
-#     Decayed [D]: 57
+# Operational [+]: 1
+#       Spare [S]: 2
+#    Tumbling [-]: 33
+#     Decayed [D]: 61
 
 1;
 
